summaryrefslogtreecommitdiffstats
path: root/kparts/componentfactory.h
diff options
context:
space:
mode:
Diffstat (limited to 'kparts/componentfactory.h')
-rw-r--r--kparts/componentfactory.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/kparts/componentfactory.h b/kparts/componentfactory.h
index 64feac1c8..ac37cabfe 100644
--- a/kparts/componentfactory.h
+++ b/kparts/componentfactory.h
@@ -82,7 +82,7 @@ namespace KParts
* \endcode
*
* @param factory The factory to ask for the creation of the component
* @param tqparentWidget the parent widget for the part
* @param widgetName the name of the part's widget
* @param parent The parent object (see TQObject constructor)
* @param name The name of the object to create (see TQObject constructor)
@@ -93,13 +93,13 @@ namespace KParts
*/
template <class T>
static T *createPartInstanceFromFactory( KParts::Factory *factory,
- TQWidget *tqparentWidget = 0,
+ TQWidget *parentWidget = 0,
const char *widgetName = 0,
TQObject *parent = 0,
const char *name = 0,
const TQStringList &args = TQStringList() )
{
- KParts::Part *object = factory->createPart( tqparentWidget, widgetName,
+ KParts::Part *object = factory->createPart( parentWidget, widgetName,
parent, name,
T::tqstaticMetaObject()->className(),
args );
@@ -156,7 +156,7 @@ namespace KParts
template <class T>
static T *createPartInstanceFromLibrary( const char *libraryName,
- TQWidget *tqparentWidget = 0,
+ TQWidget *parentWidget = 0,
const char *widgetName = 0,
TQObject *parent = 0,
const char *name = 0,
@@ -186,7 +186,7 @@ namespace KParts
*error = ErrNoFactory;
return 0;
}
- T *res = createPartInstanceFromFactory<T>( partFactory, tqparentWidget,
+ T *res = createPartInstanceFromFactory<T>( partFactory, parentWidget,
widgetName, parent, name, args );
if ( !res )
{
@@ -218,7 +218,7 @@ namespace KParts
template <class T>
static T *createPartInstanceFromService( const KService::Ptr &service,
- TQWidget *tqparentWidget = 0,
+ TQWidget *parentWidget = 0,
const char *widgetName = 0,
TQObject *parent = 0,
const char *name = 0,
@@ -233,7 +233,7 @@ namespace KParts
return 0;
}
- return createPartInstanceFromLibrary<T>( library.local8Bit().data(), tqparentWidget,
+ return createPartInstanceFromLibrary<T>( library.local8Bit().data(), parentWidget,
widgetName, parent, name, args, error );
}
@@ -267,7 +267,7 @@ namespace KParts
template <class T, class ServiceIterator>
static T *createPartInstanceFromServices( ServiceIterator begin,
ServiceIterator end,
- TQWidget *tqparentWidget = 0,
+ TQWidget *parentWidget = 0,
const char *widgetName = 0,
TQObject *parent = 0,
const char *name = 0,
@@ -281,7 +281,7 @@ namespace KParts
if ( error )
*error = 0;
- T *component = createPartInstanceFromService<T>( service, tqparentWidget,
+ T *component = createPartInstanceFromService<T>( service, parentWidget,
widgetName, parent,
name, args, error );
if ( component )
@@ -344,18 +344,18 @@ namespace KParts
* You can use this method to create a generic viewer - that can display any
* kind of file, provided that there is a ReadOnlyPart installed for it - in 5 lines:
* \code
* // Given the following: KURL url, TQWidget* tqparentWidget and TQObject* parentObject.
* TQString mimetype = KMimeType::findByURL( url )->name();
- * KParts::ReadOnlyPart* part = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString::null, tqparentWidget, 0, parentObject, 0 );
+ * KParts::ReadOnlyPart* part = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString::null, parentWidget, 0, parentObject, 0 );
* if ( part ) {
* part->openURL( url );
* part->widget()->show(); // also insert the widget into a layout, or simply use a TQVBox as tqparentWidget
* }
* \endcode
*
* @param serviceType the type of service for which to find a part, e.g. a mimetype
* @param constraint an optional constraint to pass to the trader (see KTrader)
* @param tqparentWidget the parent widget, will be set as the parent of the part's widget
* @param widgetName the name that will be given to the part's widget
* @param parent the parent object for the part itself
* @param name the name that will be given to the part
@@ -369,7 +369,7 @@ namespace KParts
template <class T>
static T *createPartInstanceFromQuery( const TQString &serviceType,
const TQString &constraint,
- TQWidget *tqparentWidget = 0,
+ TQWidget *parentWidget = 0,
const char *widgetName = 0,
TQObject *parent = 0,
const char *name = 0,
@@ -385,7 +385,7 @@ namespace KParts
}
return createPartInstanceFromServices<T>( offers.begin(), offers.end(),
- tqparentWidget, widgetName,
+ parentWidget, widgetName,
parent, name, args, error );
}
@@ -82,7 +82,7 @@ namespace KParts
*
* @param factory The factory to ask for the creation of the component
- * @param tqparentWidget the parent widget for the part
+ * @param parentWidget the parent widget for the part
* @param widgetName the name of the part's widget
* @param parent The parent object (see TQObject constructor)
@@ -344,18 +344,18 @@ namespace KParts
* kind of file, provided that there is a ReadOnlyPart installed for it - in 5 lines:
* \code
- * // Given the following: KURL url, TQWidget* tqparentWidget and TQObject* parentObject.
+ * // Given the following: KURL url, TQWidget* parentWidget and TQObject* parentObject.
* TQString mimetype = KMimeType::findByURL( url )->name();
@@ -344,18 +344,18 @@ namespace KParts
* if ( part ) {
* part->openURL( url );
- * part->widget()->show(); // also insert the widget into a layout, or simply use a TQVBox as tqparentWidget
+ * part->widget()->show(); // also insert the widget into a layout, or simply use a TQVBox as parentWidget
* }
* \endcode
@@ -344,18 +344,18 @@ namespace KParts
* @param serviceType the type of service for which to find a part, e.g. a mimetype
* @param constraint an optional constraint to pass to the trader (see KTrader)
- * @param tqparentWidget the parent widget, will be set as the parent of the part's widget
+ * @param parentWidget the parent widget, will be set as the parent of the part's widget
* @param widgetName the name that will be given to the part's widget
* @param parent the parent object for the part itself